@@ -5,6 +5,11 @@ trap : 2 3
 
 PATH=/bin:$PATH
 
+# The .param file is found in $NNDIR/.param.  Formerly this was
+# hardcoded, but with the nn-directory variable that no longer works.
+
+if [ -z "$NNDIR" ]; then NNDIR=$HOME/.nn; fi
+
 # Paramaters transferred from nn via .param file:
 #	ART_ID		Article id to cancel
 #	GROUP		Group of article to cancel
@@ -36,14 +41,14 @@ CC=""
 
 case "$1" in
 COMPLETE)
-  . $HOME/.nn/hold.param
+  . $NNDIR/hold.param
   WORK="$2"
   EMPTY_CHECK=false
-  cp $HOME/.nn/hold.work $WORK
-  rm -f $HOME/.nn/hold.*
+  cp $NNDIR/hold.work $WORK
+  rm -f $NNDIR/hold.*
   ;;
 *)
-  . $HOME/.nn/.param
+  . $NNDIR/.param
   OPERATION=$1
   ;;
 esac
@@ -130,6 +135,7 @@ case "$SPELL_CHECKER" in
   pr="$pr i)spell"
   ;;
 esac
+pr="$pr S)ign"
 pr="$pr m)ail"
 case "$OPERATION" in
 post|follow)
@@ -322,14 +328,23 @@ while $loop ; do
     esac
     ;;
 
+  S*)
+    sed -e '/^$/q' < $WORK > $WORK.HDRS
+    awk '{if (S== 1) print $0; if ($0 == "") S=1}' < $WORK > $WORK.BDY
+    pgp -stfaw < $WORK.BDY > $WORK.SGN
+    cat $WORK.HDRS $WORK.SGN > $WORK
+    rm -f $WORK.*
+    ;;
+
+
   h*)
     $AWK 'END{printf "Complete response later: (y) "}' < /dev/null
     read act
     case "$act" in
     ""|y*)
-      cp $WORK $HOME/.nn/hold.work
-      cp $HOME/.nn/.param $HOME/.nn/hold.param
-      echo "OPERATION=$OPERATION" >> $HOME/.nn/hold.param
+      cp $WORK $NNDIR/hold.work
+      cp $NNDIR/.param $NNDIR/hold.param
+      echo "OPERATION=$OPERATION" >> $NNDIR/hold.param
       case "$COPY" in
       ?*)
         rm -f $COPY
@@ -450,11 +465,11 @@ while $loop ; do
       fi
       ;;
     esac
-    grep -i -v "^Orig-To: " $TEMP | grep -i -v "^X-Newsreader: " > $FINAL
+    grep -i -v "^Orig-To: " $TEMP | grep -i -v "^User-Agent: " > $FINAL
     rm -f $TEMP
     if $XNEWSREADER ; then
       echo '/^$/i' > ${TEMP}ed
-      echo "X-Newsreader: NN version $VERSION" >> ${TEMP}ed
+      echo "User-Agent: nn/$VERSION" >> ${TEMP}ed
       echo "." >> ${TEMP}ed
       echo "w" >> ${TEMP}ed
       echo "q" >> ${TEMP}ed
@@ -600,7 +615,6 @@ esac
 	esac
 	case $x in
 	0)
-          sleep $INEWSWAIT
           ;;
 	*)
           echo $INEWS failed
@@ -611,6 +625,7 @@ esac
 		-e "/problem has been taken care of/d" \
 		-e "/mailing your article to/d" \
 		-e "/being mailed to/d" \
+		-e "/mailed to the moderator/d" \
 		-e "/is moderated/d"
       ;;
 
