@@ -9,7 +9,7 @@
 
 #undef	HAVE_MKDIR
 
-#undef	DETATCH_TERMINAL
+#undef	DETACH_TERMINAL
 
 #undef	MAILX
 #define	MAILX		"/bin/mail"
