@@ -22,7 +22,6 @@
  */
 
 #define HAVE_MULTIGROUP
-#define GIDSET_TYPE gid_t
 
 /*
  *	Define HAVE_GETHOSTNAME if your system provides a BSD like
@@ -57,7 +56,3 @@
 #undef COMPILER
 #define COMPILER xlc -qroconst -ma
 #define COMPILER_FLAGS -D_ALL_SOURCE
-
-#define HAVE_STRING_H
-#define HAVE_UNISTD_H
-#define HAVE_STDLIB_H
