@@ -30,21 +30,6 @@
 #endif
 #define SHELL		"/bin/ksh"
 
-/* Do you have /usr/include/string.h */
-#define HAVE_STRING_H /* */
-
-/* Do you have /usr/include/unistd.h */
-#define HAVE_UNISTD_H /* */
-
-/* Do you have /usr/include/stdlib.h */
-#define HAVE_STDLIB_H /* */
-
-/* Do you have /usr/include/memory.h */
-/* #define HAVE_MEMORY_H /* */
-
-/* Do you have /usr/include/fcntl.h */
-#define HAVE_FCNTL_H /* */
-
 /*
  *	Allow specification of file names to begin with a double
  *      slash "//" so that Apollo node names of form "//node" can
@@ -59,3 +44,5 @@
  */
 
 #define APOLLO_DOMAIN_OS
+
+#undef NO_MEMMOVE
