@@ -5,7 +5,6 @@
  *	preference for "termcap".
  */
 
-#define NO_DIRENT_H
 #include "s-sys5-tcap.h"
 
 #undef SIGNAL_HANDLERS_ARE_VOID
@@ -17,7 +16,7 @@ typedef struct direct Direntry;		/* BSD and SCO XENIX */
 /* #undef HAVE_MKDIR */
 #define HAVE_MKDIR
 
-#undef	DETATCH_TERMINAL
+#undef	DETACH_TERMINAL
 
 /*
  *	Define AVOID_SHELL_EXEC if the system gets confused by
@@ -29,7 +28,7 @@ typedef struct direct Direntry;		/* BSD and SCO XENIX */
 #define AVOID_SHELL_EXEC		/* */
 
 /*
- *	Specify the default mailer to be invoked by nnmail
+ *	Specify the default mailer
  */
 
 #undef	MAILX
