@@ -1,5 +1,6 @@
 /*
  *	(c) Copyright 1990, Kim Fabricius Storm.  All rights reserved.
+ *      Copyright (c) 1996-2005 Michael T Pins.  All rights reserved.
  *
  *	Digest article handling
  *
@@ -8,19 +9,26 @@
  *	contributed by Bernd Wechner (bernd@bhpcpd.kembla.oz.au).
  */
 
+#include <stdlib.h>
+#include <string.h>
+#include <strings.h>
+#include <ctype.h>
 #include "config.h"
-#include "news.h"
+#include "global.h"
 #include "debug.h"
+#include "digest.h"
+#include "news.h"
+#include "pack_name.h"
+#include "nn_term.h"
 
 /* digest.c */
 
-static char **dg_hdr_field __APROTO((register char *lp, int all));
+static char   **dg_hdr_field(register char *lp, int all);
 
-export int strict_from_parse = 2;
+int             strict_from_parse = 2;
 
 #ifdef DG_TEST
-
-#define TEST0(fmt)	 
+#define TEST0(fmt)
 #define TEST1(fmt, x)    if (Debug & DG_TEST) printf(fmt, x)
 #define TEST2(fmt, x, y) if (Debug & DG_TEST) printf(fmt, x, y)
 
@@ -29,35 +37,38 @@ export int strict_from_parse = 2;
 #define TEST0(fmt, x)
 #define TEST1(fmt, x)
 #define TEST2(fmt, x, y)
-
 #endif
 
 #define UNIFY 040
 
-static char digest_pattern[] = "igest";
+static char     digest_pattern[] = "igest";
 
 void
-init_digest_parsing()
+init_digest_parsing(void)
 {
-    register char *m;
+    register char  *m;
 
-    for (m = digest_pattern; *m; m++) *m |= UNIFY;
+    for (m = digest_pattern; *m; m++)
+	*m |= UNIFY;
 }
 
 int
-is_digest(subject)
-register char *subject;
+is_digest(register char *subject)
 {
-    register char c, *q, *m;
+    register char   c, *q, *m;
 
-    if (subject == NULL) return 0;
+    if (subject == NULL)
+	return 0;
 
     while ((c = *subject++)) {
-	if ((c | UNIFY) != ('d' | UNIFY)) continue;
+	if ((c | UNIFY) != ('d' | UNIFY))
+	    continue;
 
-	q = subject; m = digest_pattern;
+	q = subject;
+	m = digest_pattern;
 	while ((c = *m++) && (*q++ | UNIFY) == c);
-	if (c == NUL) return 1;
+	if (c == NUL)
+	    return 1;
     }
     return 0;
 }
@@ -94,64 +105,80 @@ register char *subject;
 
 #define MAX_FIELDS 10
 
-static char legal_day[]		= "SunMonTueWedThuFriSat";
-static char legal_month[]	= "JanFebMarAprMayJunJulAugSepOctNovDec";
-static int  legal_numbers[]	= { 1, 31, 0, 23, 0, 59, 0, 60, 1969, 2199 };
+static char     legal_day[] = "SunMonTueWedThuFriSat";
+static char     legal_month[] = "JanFebMarAprMayJunJulAugSepOctNovDec";
+static int      legal_numbers[] = {1, 31, 0, 23, 0, 59, 0, 60, 1969, 2199};
 
-int is_mail_from_line(line, namebuf)
-char *line;	/* Line of text to be checked */
-char *namebuf;	/* Optional buffer to place packed sender info */
+static int
+is_mail_from_line(char *line, char *namebuf)
+ /* line		Line of text to be checked */
+ /* namebuf	Optional buffer to place packed sender info */
 {
-    char *fields[MAX_FIELDS];
-    char *sender_tail = NULL;
-    register char *lp, **fp;
-    register int n, i;
+    char           *fields[MAX_FIELDS];
+    char           *sender_tail = NULL;
+    register char  *lp, **fp;
+    register int    n, i;
 
-    if (strncmp(line, "From ", 5)) return -100;
-    if (strict_from_parse == 0) return 0;
+    if (strncmp(line, "From ", 5))
+	return -100;
+    if (strict_from_parse == 0)
+	return 0;
 
     lp = line + 5;
     /* sender day mon dd hh:mm:ss year */
     for (n = 0, fp = fields; n < MAX_FIELDS; n++) {
-	while (*lp && *lp != NL && isascii(*lp) && isspace(*lp)) lp++;
-	if (*lp == NUL || *lp == NL) break;
+	while (*lp && *lp != NL && isascii(*lp) && isspace(*lp))
+	    lp++;
+	if (*lp == NUL || *lp == NL)
+	    break;
 	*fp++ = lp;
 	while (*lp && isascii(*lp) && !isspace(*lp))
-	    if (*lp++ == ':' && (n == 4 || n == 5)) break;
-	if (n == 0) sender_tail = lp;
+	    if (*lp++ == ':' && (n == 4 || n == 5))
+		break;
+	if (n == 0)
+	    sender_tail = lp;
     }
 
-    if (n < 8) return -200-n;
+    if (n < 8)
+	return -200 - n;
 
     fp = fields;
 
-    if (n > 8 && !isdigit(fp[7][0])) fp[7] = fp[8]; /* ... TZ year */
-    if (n > 9 && !isdigit(fp[7][0])) fp[7] = fp[9]; /* ... TZ DST year */
+    if (n > 8 && !isdigit(fp[7][0]))
+	fp[7] = fp[8];		/* ... TZ year */
+    if (n > 9 && !isdigit(fp[7][0]))
+	fp[7] = fp[9];		/* ... TZ DST year */
 
     if (namebuf != NULL) {
-	char x = *sender_tail;
+	char            x = *sender_tail;
 	*sender_tail = NUL;
-	pack_name(namebuf, *fp, NAME_LENGTH);
+	pack_name(namebuf, *fp, Name_Length);
 	*sender_tail = x;
     }
-
-    if (strict_from_parse == 1) return 0;
+    if (strict_from_parse == 1)
+	return 0;
 
     fp++;
     for (i = 0; i < 21; i += 3)
-	if (strncmp(*fp, &legal_day[i], 3) == 0) break;
-    if (i == 21) return -1;
+	if (strncmp(*fp, &legal_day[i], 3) == 0)
+	    break;
+    if (i == 21)
+	return -1;
 
     fp++;
     for (i = 0; i < 36; i += 3)
-	if (strncmp(*fp, &legal_month[i], 3) == 0) break;
-    if (i == 36) return -2;
+	if (strncmp(*fp, &legal_month[i], 3) == 0)
+	    break;
+    if (i == 36)
+	return -2;
 
     for (i = 0; i < 10; i += 2) {
 	lp = *++fp;
-	if (!isdigit(*lp)) return -20-i;
+	if (!isdigit(*lp))
+	    return -20 - i;
 	n = atoi(lp);
-	if (n < legal_numbers[i] || legal_numbers[i+1] < n) return -10-i;
+	if (n < legal_numbers[i] || legal_numbers[i + 1] < n)
+	    return -10 - i;
     }
     return 0;
 }
@@ -160,8 +187,8 @@ char *namebuf;	/* Optional buffer to place packed sender info */
  * expect that f is positioned at header of an article
  */
 
-static int is_mmdf_folder = 0;
-static int is_mail_folder = 0;
+static int      is_mmdf_folder = 0;
+static int      is_mail_folder = 0;
 
 /*
  * get_folder_type
@@ -174,51 +201,48 @@ static int is_mail_folder = 0;
  *	 0: normal digest,
  *	 1: UNIX mail format
  *	 2: MMDF format
- */                                        
+ */
 
-export int current_folder_type;
+int             current_folder_type;
 
-int get_folder_type(f)
-FILE *f;
+int
+get_folder_type(FILE * f)
 {
-    char line[1024];
+    char            line[1024];
 
     is_mail_folder = 0;
     is_mmdf_folder = 0;
 
-    if (fgets(line, 1024, f) == NULL)	
+    if (fgets(line, 1024, f) == NULL)
 	return current_folder_type = -1;
 
     if (strncmp(line, "\001\001\001\001\n", 5) == 0) {
 	is_mmdf_folder = 1;
 	return current_folder_type = 2;
     }
-
-    if (is_mail_from_line(line, (char *)NULL) == 0) {
+    if (is_mail_from_line(line, (char *) NULL) == 0) {
 	is_mail_folder = 1;
 	return current_folder_type = 1;
     }
-
     return current_folder_type = 0;
 }
 
 int
-get_digest_article(f, hdrbuf)
-FILE *f;
-news_header_buffer hdrbuf;
+get_digest_article(FILE * f, news_header_buffer hdrbuf)
 {
-    int cont;
+    int             cont;
 
     digest.dg_hpos = ftell(f);
-    TEST1("GET DIGEST hp=%ld\n", digest.dg_hpos);
+    TEST1("GET DIGEST hp=%ld\n", (long) digest.dg_hpos);
 
     do {
-	if (!parse_digest_header(f, 0, hdrbuf)) return -1;
+	if (!parse_digest_header(f, 0, hdrbuf))
+	    return -1;
 	digest.dg_fpos = ftell(f);
-	TEST2("END HEADER hp=%ld fp=%ld\n", digest.dg_hpos, digest.dg_fpos);
+	TEST2("END HEADER hp=%ld fp=%ld\n", (long) digest.dg_hpos, (long) digest.dg_fpos);
     } while ((cont = skip_digest_body(f)) < 0);
 
-    TEST2("END BODY lp=%ld next=%ld\n", digest.dg_lpos, ftell(f));
+    TEST2("END BODY lp=%ld next=%ld\n", (long) digest.dg_lpos, ftell(f));
 
     return cont;
 }
@@ -264,16 +288,15 @@ news_header_buffer hdrbuf;
 #define	MAX_BLANKS_END_OF	1
 
 int
-skip_digest_body(f)
-register FILE *f;
+skip_digest_body(register FILE * f)
 {
-    off_t  backup_p[BACKUP_LINES];
-    int	   line_type[BACKUP_LINES];
-    register int backup_index, backup_count;
-    int    more_header_lines, end_or_asterisks, blanks;
-    int    colon_lines;
-    char   line[1024];
-    register char *cp;
+    long            backup_p[BACKUP_LINES];
+    int             line_type[BACKUP_LINES];
+    register int    backup_index, backup_count;
+    int             more_header_lines, end_or_asterisks, blanks;
+    int             colon_lines;
+    char            line[1024];
+    register char  *cp;
 
 #define	decrease_index()	\
     if (--backup_index < 0) backup_index = BACKUP_LINES - 1
@@ -285,15 +308,17 @@ register FILE *f;
     digest.dg_lines = 0;
 
 
- next_line:
+next_line:
     more_header_lines = 0;
     colon_lines = 0;
 
- next_possible_header_line:
+next_possible_header_line:
     digest.dg_lines++;
 
-    if (++backup_index == BACKUP_LINES) backup_index = 0;
-    if (backup_count < BACKUP_LINES) backup_count++;
+    if (++backup_index == BACKUP_LINES)
+	backup_index = 0;
+    if (backup_count < BACKUP_LINES)
+	backup_count++;
 
     backup_p[backup_index] = ftell(f);
     line_type[backup_index] = LN_TEXT;
@@ -306,32 +331,32 @@ register FILE *f;
 	    is_mmdf_folder = 0;
 	    return 0;
 	}
-
 	/* end of file => look for "****" or "End of" line */
 
 	if (end_or_asterisks)
 	    while (--backup_count >= 0) {
 		--digest.dg_lines;
 		decrease_index();
-		if (line_type[backup_index] & (LN_ASTERISK | LN_END_OF)) break;
+		if (line_type[backup_index] & (LN_ASTERISK | LN_END_OF))
+		    break;
 	    }
 
 	digest.dg_lpos = backup_p[backup_index];
 
-	if (digest.dg_lines == 0) return 0;
+	if (digest.dg_lines == 0)
+	    return 0;
 
 	while (--backup_count >= 0) {
 	    --digest.dg_lines;
 	    digest.dg_lpos = backup_p[backup_index];
 	    decrease_index();
 	    if ((line_type[backup_index] &
-		(LN_ASTERISK | LN_END_OF | LN_BLANK | LN_DASHED)) == 0)
+		 (LN_ASTERISK | LN_END_OF | LN_BLANK | LN_DASHED)) == 0)
 		break;
 	}
 
-	return 0;	/* no article follows */
+	return 0;		/* no article follows */
     }
-
     TEST1("\n>>%-.50s ==>>", line);
 
     if (is_mmdf_folder) {
@@ -343,7 +368,6 @@ register FILE *f;
 	--digest.dg_lines;
 	return (digest.dg_lines <= 0) ? -1 : 1;
     }
-
     for (cp = line; *cp && isascii(*cp) && isspace(*cp); cp++);
 
     if (*cp == NUL) {
@@ -351,41 +375,43 @@ register FILE *f;
 	line_type[backup_index] = LN_BLANK;
 	goto next_line;
     }
-
     if (is_mail_folder) {
 	/* in a mail folder we simply look for the next "From " line */
-	if (line[0] != 'F' || is_mail_from_line(line, (char *)NULL) < 0)
+	if (line[0] != 'F' || is_mail_from_line(line, (char *) NULL) < 0)
 	    goto next_line;
 
 	line_type[backup_index] = LN_HEADER;
 	fseek(f, backup_p[backup_index], 0);
 	goto found_mail_header;
     }
-
     blanks = cp - line;
 
     if (*cp == '-') {
-	if (blanks > MAX_BLANKS_DASH) goto next_line;
+	if (blanks > MAX_BLANKS_DASH)
+	    goto next_line;
 
-	while (*cp == '-') cp++;
+	while (*cp == '-')
+	    cp++;
 	if (cp - line - blanks > MIN_DASHES) {
-	    while (*cp && (*cp == '-' || (isascii(*cp) && isspace(*cp)))) cp++;
+	    while (*cp && (*cp == '-' || (isascii(*cp) && isspace(*cp))))
+		cp++;
 	    if (*cp == NUL) {
 		TEST0("DASHED");
 
 		line_type[backup_index] = LN_DASHED;
 	    }
-
 	}
 	goto next_line;
     }
-
     if (*cp == '*') {
-	if (blanks > MAX_BLANKS_ASTERISK) goto next_line;
+	if (blanks > MAX_BLANKS_ASTERISK)
+	    goto next_line;
 
-	while (*cp == '*') cp++;
+	while (*cp == '*')
+	    cp++;
 	if (cp - line - blanks > MIN_ASTERISKS) {
-	    while (*cp && (*cp == '*' || (isascii(*cp) && isspace(*cp)))) cp++;
+	    while (*cp && (*cp == '*' || (isascii(*cp) && isspace(*cp))))
+		cp++;
 	    if (*cp == NUL) {
 		TEST0("ASTERISK");
 		line_type[backup_index] = LN_ASTERISK;
@@ -394,7 +420,6 @@ register FILE *f;
 	}
 	goto next_line;
     }
-
     if (blanks <= MAX_BLANKS_END_OF &&
 	*cp == 'E' && strncmp(cp, "End of ", 7) == 0) {
 	TEST0("END_OF_");
@@ -402,19 +427,18 @@ register FILE *f;
 	end_or_asterisks++;
 	goto next_line;
     }
-
     if (blanks)
 	goto next_possible_header_line;
 /* must be able to handle continued lines in sub-digest headers...
 	goto next_line;
 */
 
-    if (!dg_hdr_field(line, 0))
-    {
-	char *colon;
+    if (!dg_hdr_field(line, 0)) {
+	char           *colon;
 	if ((colon = strchr(line, ':'))) {
 	    for (cp = line; cp < colon; cp++)
-		if (!isascii(*cp) || isspace(*cp)) break;
+		if (!isascii(*cp) || isspace(*cp))
+		    break;
 	    if (cp == colon) {
 		TEST0("COLON");
 		colon_lines++;
@@ -422,15 +446,13 @@ register FILE *f;
 		goto next_possible_header_line;
 	    }
 	}
-	if (is_mail_from_line(line, (char *)NULL) == 0) {
+	if (is_mail_from_line(line, (char *) NULL) == 0) {
 	    TEST0("FROM_");
 	    colon_lines++;
 	    line_type[backup_index] = LN_HEADER;
 	}
-
 	goto next_possible_header_line;
     }
-
     TEST0("HEADER");
 
     line_type[backup_index] = LN_HEADER;
@@ -445,9 +467,11 @@ register FILE *f;
     for (;;) {
 	fseek(f, backup_p[backup_index], 0);
 	if (line_type[backup_index] == LN_HEADER)
-	    if (--colon_lines <= 0) break;
+	    if (--colon_lines <= 0)
+		break;
 	--digest.dg_lines;
-	if (--backup_count == 0) break;
+	if (--backup_count == 0)
+	    break;
 	decrease_index();
 	if ((line_type[backup_index] & (LN_HEADER | LN_TEXT)) == 0)
 	    break;
@@ -457,12 +481,12 @@ register FILE *f;
 	TEST0("Skipped empty article\n");
 	return -1;
     }
-
- found_mail_header:
+found_mail_header:
 
     for (;;) {
 	digest.dg_lpos = backup_p[backup_index];
-	if (--backup_count < 0) break;
+	if (--backup_count < 0)
+	    break;
 	decrease_index();
 	if ((line_type[backup_index] & (LN_BLANK | LN_DASHED)) == 0)
 	    break;
@@ -473,10 +497,7 @@ register FILE *f;
 }
 
 int
-parse_digest_header(f, all, hdrbuf)
-FILE *f;
-int all;
-news_header_buffer hdrbuf;
+parse_digest_header(FILE * f, int all, news_header_buffer hdrbuf)
 {
     digest.dg_date = digest.dg_from = digest.dg_subj = digest.dg_to = NULL;
 
@@ -486,71 +507,71 @@ news_header_buffer hdrbuf;
 }
 
 
-static char **dg_hdr_field(lp, all)
-register char *lp;
-int all;
+static char   **
+dg_hdr_field(register char *lp, int all)
 {
-    static char *dummy;
-    static char namebuf[NAME_LENGTH+1];
+    static char    *dummy;
+    static char     namebuf[33];
 
-#ifdef __STDC__
 #define check(name, lgt, field) \
-    if (isascii(lp[lgt]) && isspace(lp[lgt]) && strncmp(name, lp, lgt) == 0) {\
+    if (isascii(lp[lgt]) && isspace(lp[lgt]) \
+	&& strncasecmp(name, lp, lgt) == 0) {\
 	TEST0("MATCH: " #field " "); \
 	return &digest.field; \
     }
-#else /* crock old K&R compiler */
-#define check(name, lgt, field) \
-    if (isascii(lp[lgt]) && isspace(lp[lgt]) && strncmp(name, lp, lgt) == 0) {\
-	TEST0("MATCH: field "); \
-	return &digest.field; \
-    }
-#endif
 
     TEST1("\nPARSE[%.20s] ==>> ", lp);
 
     switch (*lp++) {
 
-     case '\001':
-	/* In an mmdf folder ^A^A^A^A is skipped at beginning of header */
-	if (!is_mmdf_folder) break;
-	if (strncmp(lp, "\001\001\001\n", 4)) break;
-	digest.dg_hpos += 5;
-	return NULL;
+	case '\001':
+	    /* In an mmdf folder ^A^A^A^A is skipped at beginning of header */
+	    if (!is_mmdf_folder)
+		break;
+	    if (strncmp(lp, "\001\001\001\n", 4))
+		break;
+	    digest.dg_hpos += 5;
+	    return NULL;
 
-     case 'D':
-     case 'd':
-	check("ate:",	4, dg_date);
-	break;
+	case 'D':
+	case 'd':
+	    check("ate:", 4, dg_date);
+	    break;
 
-     case 'F':
-     case 'f':
-	check("rom:",	4, dg_from);
-	if (!is_mail_folder) break;
-	if (*--lp != 'F') break;
-	if (is_mail_from_line(lp, namebuf) < 0) break;
-	/* Store packed sender in dg_from here and return dummy to parser */
-	if (digest.dg_from == NULL) digest.dg_from = namebuf;
-	return &dummy;
+	case 'F':
+	case 'f':
+	    check("rom:", 4, dg_from);
+	    if (!is_mail_folder)
+		break;
+	    if (*--lp != 'F')
+		break;
+	    if (is_mail_from_line(lp, namebuf) < 0)
+		break;
+	    /* Store packed sender in dg_from here and return dummy to parser */
+	    if (digest.dg_from == NULL)
+		digest.dg_from = namebuf;
+	    return &dummy;
 
-     case 'R':
-     case 'r':
-	if (!all) break;
-	check("e:",	2, dg_subj);
-	break;
+	case 'R':
+	case 'r':
+	    if (!all)
+		break;
+	    check("e:", 2, dg_subj);
+	    break;
 
-     case 'S':
-     case 's':
-	check("ubject:", 7, dg_subj);
-	check("ubject",	6, dg_subj);
-	break;
+	case 'S':
+	case 's':
+	    check("ubject:", 7, dg_subj);
+	    check("ubject", 6, dg_subj);
+	    break;
 
-     case 'T':
-     case 't':
-	check("itle:",	5, dg_subj);
-	if (!all) break;
-	check("o:",	2, dg_to);
-	break;
+	case 'T':
+	case 't':
+	    check("itle:", 5, dg_subj);
+	    if (!all)
+		break;
+	    check("o:", 2, dg_to);
+	    break;
     }
 
 #undef check
