@@ -94,14 +94,6 @@ parseargv_variables(char **av, int ac)
 	    set_variable(*av, 1, value);
 	    *--value = '=';	/* restore for later parsing to skip it */
 	}
-
-	/*
-	 * OLSON gross hack; see comments at call in nn.c; because this is so
-	 * gross, I'm not doing it cleanly or "right"
-	 */
-	else if (**av == '-' && (strchr(*av, 'x') || strchr(*av, 'N'))) {
-	    no_update++;
-	}
     }
 }
 
